import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent

    property alias itemAIDType: aidInput.itemAIDType
    property string editionID: "PRO"

    property string itemReviewDTSHR: ""
    property string itemContextHR: ""
    property string itemLocation: ""

    property string itemStartDTSHR: ""
    property string itemRepeatDTSHR: ""
    property string itemEndDTSHR: ""
    property string itemDuration: ""

    property string itemSecurityLevelHR: ""

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    property int inputInset: 12

    signal aidTypeTriggered(int newAIDType);
    signal displayDatePickerAt(string field, int x, int y);
    signal displayRepeatPickerAt(string field, int x, int y);
    signal displayContextPickerAt(string contextType, int x, int y);
    signal displaySecurityLevelPickerAt(string field, int x, int y);
    signal locationUpdated(string newLocation);
    signal durationUpdated(string newDuration);


    property Gradient backgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 1.0; color: "#d9d9d9" }
    }

    Rectangle {
        id: background
        anchors.fill: parent
        color: "transparent"

        AIActionDetailsAIDInput {
            id: aidInput
            anchors { left: parent.left; right: parent.right; top: parent.top; topMargin: 6 }
            height: 21
            visible: (editionID != "ME")

            onTriggered: {
                console.debug("AID in Review Panel changed to: ")
                console.debug(newAIDType)

                QtHandler.closeAllPicker()

                aidTypeTriggered(newAIDType)
            }
        }

        AIActionDetailsLineInput {
            id: nextReviewInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: (editionID == "ME") ? parent.top : aidInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("Next Review:")
            lineInputType: 1
            itemText: maincomponent.itemReviewDTSHR

            onDateUpdated: {
                console.debug("Next Review Date in Review Panel changed to: ")
                console.debug(newSQLDate)
                //commentUpdated(newComment)
            }

            onDisplayDatePickerAt: {
                console.debug("Date Picker requested in Review Panel")
                //maincomponent.displayDatePickerAt("review_dt", 446, 138)
                maincomponent.displayDatePickerAt("review_dt", 446, nextReviewInput.y + 105)
            }
        }

        AIActionDetailsLineInput {
            id: contextInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: nextReviewInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("Context:")
            lineInputType: 2
            itemText: maincomponent.itemContextHR

            onDisplayContextPickerAt: {
                console.debug("Context Picker requested in Review Panel")
                //maincomponent.displayContextPickerAt(contextType, 446, 164)
                maincomponent.displayContextPickerAt(contextType, 446, contextInput.y + 105)
            }
        }

        AIActionDetailsLineInput {
            id: locationInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: contextInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("Location:")
            lineInputType: 0
            itemText: maincomponent.itemLocation

            onTextUpdated: {
                console.debug("Location in Review Panel changed to: ")
                console.debug(newText)
                locationUpdated(newText)
            }

            onItemClicked: {
                console.debug("locationInput clicked - closing Picker")
                QtHandler.closeAllPicker();
            }
        }

        AIActionDetailsLineInput {
            id: startDateInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: locationInput.bottom; topMargin: 18 }
            height: 21

            itemLabelText: qsTr("Start Date:")
            lineInputType: 1
            itemText: maincomponent.itemStartDTSHR

            onDateUpdated: {
                //console.debug("Start Date in Review Panel changed to: ")
                //console.debug(newSQLDate)
                //commentUpdated(newComment)
            }

            onDisplayDatePickerAt: {
                //console.debug("Date Picker requested in More Panel")
                maincomponent.displayDatePickerAt("start_dt", 446, startDateInput.y + 105)
            }
        }

        AIActionDetailsLineInput {
            id: repeatInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: startDateInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("Repeat:")
            lineInputType: 4
            itemText: maincomponent.itemRepeatDTSHR

            onDateUpdated: {
                //console.debug("Repeat in Review Panel changed to: ")
                //console.debug(newSQLDate)
                //commentUpdated(newComment)
            }

            onDisplayRepeatPickerAt: {
                //console.debug("Repeat Picker requested in More Panel")
                //maincomponent.displayRepeatPickerAt(field, 446, 177)
                maincomponent.displayRepeatPickerAt(field, 446, repeatInput.y + 105)
            }
        }

        AIActionDetailsLineInput {
            id: endDateInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: repeatInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("End Date:")
            lineInputType: 1
            itemText: maincomponent.itemEndDTSHR

            onDateUpdated: {
                //console.debug("End Date in Review Panel changed to: ")
                //console.debug(newSQLDate)
                //commentUpdated(newComment)
            }

            onDisplayDatePickerAt: {
                //console.debug("Date Picker requested in More Panel")
                //maincomponent.displayDatePickerAt("end_dt", 446, 204)
                maincomponent.displayDatePickerAt("end_dt", 446, endDateInput.y + 105)
            }
        }

        AIActionDetailsLineInput {
            id: durationInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: endDateInput.bottom; topMargin: 6 }
            height: 21

            itemLabelText: qsTr("Duration (h):")

            lineInputType: 0
            itemText: maincomponent.itemDuration

            onTextUpdated: {
                //console.debug("Duration in More Panel changed to: ")
                //console.debug(newText)
                durationUpdated(newText)
            }

            onItemClicked: {
                console.debug("durationInput clicked - closing Picker")
                QtHandler.closeAllPicker();
            }
        }

        AIActionDetailsLineInput {
            id: securityLevelInput
            anchors { left: parent.left; leftMargin: maincomponent.inputInset; right: parent.right; rightMargin:maincomponent.inputInset; top: durationInput.bottom; topMargin: 18 }
            height: 21
            visible: (editionID != "ME")

            itemLabelText: qsTr("Security:")
            lineInputType: 3
            itemText: maincomponent.itemSecurityLevelHR

            onDisplaySecurityLevelPickerAt: {
                console.debug("Security Picker requested in Review Panel")
                maincomponent.displaySecurityLevelPickerAt(field, 446, securityLevelInput.y + 105)
            }
        }
    }
}
